@@ -49,17 +49,25 @@ class NumbersTest(unittest.TestCase):
 
 class TestStringMethods(unittest.TestCase):
 
+  def testVersion(self):
+    googlenews = GoogleNews()
+    version = '1.6.0'
+    self.assertIn(version, googlenews.getVersion())
+    print('Latest version matched')
+    
   def testResultContainsKeyword(self):
     googlenews = GoogleNews()
     googlenews.search(keyword)
     result = googlenews.result()[0]
-    self.assertIn(keyword.lower(), result.get('desc').lower())
+    print(result.get('title').lower()+result.get('desc').lower())
+    self.assertIn(keyword.lower(), result.get('title').lower()+result.get('desc').lower())
     print('Result contains keyword')
 
   def testResultHasLink(self):
     googlenews = GoogleNews()
     googlenews.search(keyword)
     result = googlenews.result()[0]
+    print(result.get('link').lower())
     self.assertIn('http', result.get('link').lower())
     print('Result contains http link')
 
@@ -67,6 +75,7 @@ class TestStringMethods(unittest.TestCase):
     googlenews = GoogleNews()
     googlenews.search(keyword)
     result = googlenews.result()[0]
+    print(result.get('img').lower())
     self.assertIn('base64', result.get('img').lower())
     print('Result contains image')
 
@@ -74,6 +83,7 @@ class TestStringMethods(unittest.TestCase):
     googlenews = GoogleNews()
     googlenews.search(keyword)
     result = googlenews.result()[0]
+    print(result.get('title').lower())
     self.assertIsNot('', result.get('title').lower())
     print('Result title is not empty')
 
@@ -81,6 +91,7 @@ class TestStringMethods(unittest.TestCase):
     googlenews = GoogleNews()
     googlenews.search(keyword)
     result = googlenews.result()[0]
+    print(result.get('media').lower())
     self.assertIsNot('', result.get('media').lower())
     print('Result media is not empty')
 
